@@ -5,11 +5,11 @@ AIcalcu <- function(data,
                     binPredInd,
                     contCovStd = FALSE) {
   results <- list()
-
+  
   # get the original sample size
   nSub <- nrow(data)
   MVarNamLength <- nchar(Mprefix)
-
+  
   # get taxa data
   micros <-
     lapply(substr(colnames(data), 1, MVarNamLength), function(x) {
@@ -17,16 +17,16 @@ AIcalcu <- function(data,
     })
   microPositions <- which(micros == 1)
   rm(micros)
-
+  
   nTaxa <- length(microPositions)
   nNorm <- nTaxa - 1
   taxaNames <- colnames(data)[microPositions]
   rm(microPositions)
-
+  
   # rearrange taxa names
   otherTaxaNames <- taxaNames[(taxaNames != ref)]
   taxaNames <- c(otherTaxaNames, ref)
-
+  
   # get predictor data
   xVarNamLength <- nchar(covsPrefix)
   predics <-
@@ -37,36 +37,37 @@ AIcalcu <- function(data,
   predNames <- colnames(data)[predPositions]
   nPredics <- length(predNames)
   rm(predics, predPositions)
-
+  
   # taxa data
-  w <- data[, taxaNames]
-
+  w <- data[, taxaNames, drop = FALSE]
+  
   # extract x data
-  xData <- data[, predNames]
-
+  xData <- data[, predNames, drop = FALSE]
+  
   if (contCovStd & (length(binPredInd) < nPredics)) {
     if (length(binPredInd) == 0) {
       xData <- scale(xData, center = FALSE)
     } else {
-      xData[, -binPredInd] <- scale(xData[, -binPredInd], center = FALSE)
+      xData[,-binPredInd] <-
+        scale(xData[,-binPredInd, drop = FALSE], center = FALSE)
     }
   }
-
+  
   rm(data, predNames)
-
+  
   # transform data using log-ratio, creat Ai and Li
   l <- rep(NA, nSub)
   lLast <- rep(NA, nSub)
   logRatiow <- list()
   A <- list()
   for (i in seq_len(nSub)) {
-    taxa.nonzero <- which(w[i, ] != 0)
+    taxa.nonzero <- which(w[i,] != 0)
     if (length(taxa.nonzero) > 0) {
       lLast[i] <- max(taxa.nonzero)
     } else {
       lLast[i] <- 0
     }
-
+    
     if (length(taxa.nonzero) > 0) {
       last.nonzero <- lLast[i]
       logwi <- as.numeric(log(w[i, taxa.nonzero]))
@@ -75,12 +76,14 @@ AIcalcu <- function(data,
         logRatiow[[i]] <- logwi[seq_len(l[i] - 1)] - logwi[l[i]]
         zero.m <- matrix(0, nrow = l[i] - 1, ncol = nNorm)
         if (last.nonzero == nTaxa) {
-          zero.m[cbind(seq_len(l[i] - 1), taxa.nonzero[seq_len(l[i] - 1)])] <- 1
+          zero.m[cbind(seq_len(l[i] - 1), taxa.nonzero[seq_len(l[i] - 1)])] <-
+            1
         } else {
-          zero.m[cbind(seq_len(l[i] - 1), taxa.nonzero[seq_len(l[i] - 1)])] <- 1
+          zero.m[cbind(seq_len(l[i] - 1), taxa.nonzero[seq_len(l[i] - 1)])] <-
+            1
           zero.m[, taxa.nonzero[l[i]]] <- -1
         }
-
+        
         A[[i]] <- MatrixExtra::as.csc.matrix(zero.m)
         rm(zero.m)
       } else {
@@ -93,16 +96,16 @@ AIcalcu <- function(data,
       A[[i]] <- NA
     }
   }
-
+  
   # obtain the list of samples whose have at least 2 non-zero taxa
   twoList <- which(l > 1)
   lengthTwoList <- length(twoList)
-
+  
   rm(w)
-
+  
   results$xData <- xData
   rm(xData)
-
+  
   results$logRatiow <- logRatiow
   rm(logRatiow)
   results$A <- A
