@@ -12,22 +12,9 @@ runlinear=function(
 
   results=list()
 
-  nBeta=ncol(x)
-
-  nObsAll=length(y)
-
-
-
-  lm_res<-lm(as.vector(y)~as.matrix(x)-1)
-
-  full_name_coef<-names(lm_res$coefficients)
-  valid_coef<-summary(lm_res)$coefficients
-  bootResu<-matrix(nrow = length(full_name_coef),ncol = 4)
-  rownames(bootResu)<-full_name_coef
-  bootResu[rownames(bootResu)%in%rownames(valid_coef),]<-valid_coef
-
-
 
+  bootResu<-lm_sparse(x = x, y = y)
+  
   p_value_est<-bootResu[,4]
   p_value_est_noint<-p_value_est[-seq(1,length(p_value_est),by=(nPredics+1))]
   p_value_est_noint_adj<-p.adjust(p_value_est_noint,adjust_method)
